### Name: adaptMetropGibbs
### Title: Adaptive Metropolis within Gibbs algorithm
### Aliases: adaptMetropGibbs
### Keywords: misc

### ** Examples

## Not run: 
##D ## Not run: 
##D ##########################
##D ##Example of fitting a
##D ##a non-linear model
##D ##########################
##D set.seed(1)
##D 
##D ##Simulate some data
##D par <- c(0.1,0.1,3,1)
##D tau.sq <- 0.01
##D 
##D fn <- function(par,x){
##D   par[1]+par[2]^(1-(log(x/par[3])/par[4])^2)
##D }
##D 
##D n <- 200
##D x <- seq(1,10,0.1)
##D y <- rnorm(length(x), fn(par,x), sqrt(tau.sq))
##D 
##D ##Define the log target density
##D ltd <- function(theta, x, y, fn, IG.a, IG.b){
##D 
##D   theta[2:5] <- exp(theta[2:5])
##D   tau.sq <- theta[5]
##D 
##D   y.hat <- fn(theta[1:4],x)
##D 
##D   ##likelihood
##D   logl <- -(n/2)*log(tau.sq)-(1/(2*tau.sq))*sum((y-y.hat)^2)
##D 
##D   ##priors IG on tau.sq and the rest flat
##D   logl <- logl-(IG.a+1)*log(tau.sq)-IG.b/tau.sq
##D 
##D   ##Jacobian adjustments
##D   logl <- logl+sum(log(theta[2:5]))
##D   
##D   return(logl)  
##D }
##D 
##D ##Give some reasonable starting values,
##D ##note the transformation
##D starting <- c(0.5, log(0.5), log(5), log(3), log(1))
##D 
##D m.1 <- adaptMetropGibbs(ltd, starting=starting,
##D                         batch=1200, batch.length=25, 
##D                         x=x, y=y, fn=fn, IG.a=2, IG.b=0.01)
##D 
##D ##Back transform
##D m.1$p.samples[,2:5] <- exp(m.1$p.samples[,2:5])
##D 
##D ##Summary with 95
##D burn.in <- 10000
##D 
##D fn.pred <- function(par,x){
##D   rnorm(length(x), fn(par[1:4],x), sqrt(par[5]))
##D }
##D 
##D post.curves <-
##D   t(apply(m.1$p.samples[burn.in:nrow(m.1$p.samples),], 1, fn.pred, x))
##D 
##D post.curves.quants <- summary(mcmc(post.curves))$quantiles
##D 
##D plot(x, y, pch=19, xlab="x", ylab="f(x)")
##D lines(x, post.curves.quants[,1], lty="dashed", col="blue")
##D lines(x, post.curves.quants[,3])
##D lines(x, post.curves.quants[,5], lty="dashed", col="blue")
##D 
##D ########################################
##D ##Now some real data. There are way too
##D ##few data for this model so we use a
##D ##slightly informative normal prior on
##D ##the parameters.
##D ########################################
##D 
##D fn <- function(par,x){
##D   par[1]-(par[2]^(1-(log(x/par[3])/par[4])^2))
##D }
##D 
##D x <- c(5,6,7,17,17,18,39,55,60)
##D y <- c(47.54,62.10,37.29,24.74,22.64,32.60,11.16,9.65,14.83)
##D n <- length(x)
##D 
##D ##Define the log target density
##D ltd <- function(theta, x, y, fn, IG.a, IG.b){
##D 
##D   theta[2:5] <- exp(theta[2:5])
##D   tau.sq <- theta[5]
##D 
##D   y.hat <- fn(theta[1:4],x)
##D 
##D   ##likelihood
##D   logl <- -(n/2)*log(tau.sq)-(1/(2*tau.sq))*sum((y-y.hat)^2)
##D 
##D   ##priors IG on tau.sq and the rest normal
##D   logl <- logl-(IG.a+1)*log(tau.sq)-IG.b/tau.sq+
##D     sum(dnorm(theta[1:4], rep(0,4), 500, log = TRUE))
##D   
##D   ##Jacobian adjustments
##D   logl <- logl+sum(log(theta[2:5]))
##D   
##D   return(logl)  
##D }
##D 
##D ##Give some reasonable starting values,
##D ##note the transformation
##D starting <- c(50, log(40), log(40), log(2), log(0.1))
##D 
##D m.1 <- adaptMetropGibbs(ltd, starting=starting,
##D                         batch=1500, batch.length=25, 
##D                         x=x, y=y, fn=fn, IG.a=2, IG.b=10)
##D 
##D ##Back transform
##D m.1$p.samples[,2:5] <- exp(m.1$p.samples[,2:5])
##D 
##D ##Summary with 95
##D burn.in <- 20000
##D 
##D x.pred <- seq(0, 60, seq=0.1)
##D 
##D fn.pred <- function(par,x){
##D   rnorm(length(x), fn(par[1:4],x), sqrt(par[5]))
##D }
##D 
##D post.curves <-
##D   t(apply(m.1$p.samples[burn.in:nrow(m.1$p.samples),], 1, fn.pred, x.pred))
##D 
##D post.curves.quants <- summary(mcmc(post.curves))$quantiles
##D 
##D plot(x, y, pch=19, xlab="x", ylab="f(x)", xlim=c(0,60), ylim=c(0,100))
##D lines(x.pred, post.curves.quants[,1], lty="dashed", col="blue")
##D lines(x.pred, post.curves.quants[,3])
##D lines(x.pred, post.curves.quants[,5], lty="dashed", col="blue")
##D 
##D ## End(Not run)
##D 
##D 
## End(Not run)



