### Name: spDIC
### Title: Calculates model DIC and associated statistics given a
###   bayesLMRef, bayesLMConjugate, spGGT, spLM, spMvLM, bayesGeostatExact
###   object
### Aliases: spDIC
### Keywords: misc

### ** Examples

## Not run: 
##D ###########################################
##D ##          DIC for spLM
##D ###########################################
##D 
##D ##Use some more observations
##D data(rf.n200.dat)
##D 
##D Y <- rf.n200.dat$Y
##D coords <- as.matrix(rf.n200.dat[,c("x.coords","y.coords")])
##D 
##D ##############################
##D ##With and without predictive
##D ##process
##D ##############################
##D m.1a <- spLM(Y~1, coords=coords, knots=c(5, 5, 0),
##D              starting=list("phi"=0.6,"sigma.sq"=1, "tau.sq"=1),
##D              sp.tuning=list("phi"=0.01, "sigma.sq"=0.05, "tau.sq"=0.05),
##D              priors=list("phi.Unif"=c(0.3, 3), "sigma.sq.IG"=c(2, 1),
##D                "tau.sq.IG"=c(2, 1)),
##D              cov.model="exponential",
##D              n.samples=1000, verbose=TRUE, n.report=100)
##D 
##D print(spDIC(m.1a, start=100, thin=2, DIC.marg=TRUE, DIC.unmarg=TRUE))
##D 
##D m.1b <- spLM(Y~1, coords=coords, knots=c(7, 7, 0),
##D              starting=list("phi"=0.6,"sigma.sq"=1, "tau.sq"=1),
##D              sp.tuning=list("phi"=0.01, "sigma.sq"=0.05, "tau.sq"=0.05),
##D              priors=list("phi.Unif"=c(0.3, 3), "sigma.sq.IG"=c(2, 1),
##D                "tau.sq.IG"=c(2, 1)),
##D              cov.model="exponential",
##D              n.samples=1000, verbose=TRUE, n.report=100)
##D 
##D print(spDIC(m.1b, start=100, thin=2, DIC.marg=TRUE, DIC.unmarg=TRUE))
##D 
##D m.2 <- spLM(Y~1, coords=coords, 
##D              starting=list("phi"=0.6,"sigma.sq"=1, "tau.sq"=1),
##D              sp.tuning=list("phi"=0.01, "sigma.sq"=0.05, "tau.sq"=0.05),
##D              priors=list("phi.Unif"=c(0.3, 3), "sigma.sq.IG"=c(2, 1),
##D                "tau.sq.IG"=c(2, 1)),
##D              cov.model="exponential",
##D              n.samples=1000, verbose=TRUE, n.report=100)
##D 
##D print(spDIC(m.2, start=100, thin=2, DIC.marg=TRUE, DIC.unmarg=TRUE))
##D 
##D ###########################################
##D ##    DIC for bayesGeostatExact
##D ###########################################
##D data(FORMGMT.dat)
##D 
##D n = nrow(FORMGMT.dat)
##D p = 5 ##an intercept an four covariates
##D 
##D n.samples <- 10
##D 
##D coords <- cbind(FORMGMT.dat$Longi, FORMGMT.dat$Lat)
##D 
##D phi <- 3/0.07
##D 
##D beta.prior.mean <- rep(0, times=p)
##D beta.prior.precision <- matrix(0, nrow=p, ncol=p)
##D 
##D alpha <- 1/1.5
##D 
##D sigma.sq.prior.shape <- 2.0
##D sigma.sq.prior.rate <- 10.0
##D 
##D ##With covariates
##D m.3 <-
##D   bayesGeostatExact(Y~X1+X2+X3+X4, data=FORMGMT.dat,
##D                       n.samples=n.samples,
##D                       beta.prior.mean=beta.prior.mean,
##D                       beta.prior.precision=beta.prior.precision,
##D                       coords=coords, phi=phi, alpha=alpha,
##D                       sigma.sq.prior.shape=sigma.sq.prior.shape,
##D                       sigma.sq.prior.rate=sigma.sq.prior.rate,
##D                       sp.effects=FALSE)
##D 
##D print(spDIC(m.3, DIC.marg=TRUE, DIC.unmarg=FALSE))
##D 
##D ##Without covariates
##D p <- 1 ##intercept only
##D beta.prior.mean <- 0
##D beta.prior.precision <- 0
##D 
##D m.4 <-
##D   bayesGeostatExact(Y~1, data=FORMGMT.dat,
##D                       n.samples=n.samples,
##D                       beta.prior.mean=beta.prior.mean,
##D                       beta.prior.precision=beta.prior.precision,
##D                       coords=coords, phi=phi, alpha=alpha,
##D                       sigma.sq.prior.shape=sigma.sq.prior.shape,
##D                       sigma.sq.prior.rate=sigma.sq.prior.rate,
##D                       sp.effects=FALSE)
##D 
##D print(spDIC(m.4, DIC.marg=TRUE, DIC.unmarg=FALSE))
##D 
##D ##Lower DIC is better, so go with the covariates.
##D 
##D ###########################################
##D ##         DIC for spGGT
##D ###########################################
##D data(FBC07.dat)
##D 
##D Y.2 <- FBC07.dat[1:100,"Y.2"]
##D coords <- as.matrix(FBC07.dat[1:100,c("coord.X", "coord.Y")])
##D 
##D ##m.5 some model with spGGT.
##D K.prior <- prior(dist="IG", shape=2, scale=5)
##D Psi.prior <- prior(dist="IG", shape=2, scale=5)
##D phi.prior <- prior(dist="UNIF", a=0.06, b=3)
##D 
##D var.update.control <-
##D   list("K"=list(starting=5, tuning=0.1, prior=K.prior),
##D        "Psi"=list(starting=5, tuning=0.1, prior=Psi.prior),
##D        "phi"=list(starting=0.1, tuning=0.5, prior=phi.prior)
##D        )
##D 
##D beta.control <- list(update="GIBBS", prior=prior(dist="FLAT"))
##D 
##D run.control <- list("n.samples"=1000, "sp.effects"=TRUE)
##D 
##D m.5 <-
##D   spGGT(formula=Y.2~1, run.control=run.control,
##D          coords=coords, var.update.control=var.update.control,
##D          beta.update.control=beta.control,
##D          cov.model="exponential")
##D 
##D ##Now with the spGGT object, m.5, calculate the DIC
##D ##for both the unmarginalized and marginalized models.
##D ##The likelihoods for these models are given by equation 6 and 7
##D ##within the vignette.
##D 
##D DIC <- spDIC(m.5)
##D print(DIC)
##D 
##D ###########################################
##D ##     Compare DIC between non-spatial
##D ##           and spatial models
##D ###########################################
##D 
##D data(FBC07.dat)
##D Y.2 <- FBC07.dat[1:150,"Y.2"]
##D coords <- as.matrix(FBC07.dat[1:150,c("coord.X", "coord.Y")])
##D 
##D ##############################
##D ##Non-spatial model
##D ##############################
##D m.1 <- bayesLMConjugate(Y.2~1, n.samples = 2000,
##D                           beta.prior.mean=0, beta.prior.precision=0,
##D                           prior.shape=-0.5, prior.rate=0)
##D 
##D summary(m.1$p.samples)
##D 
##D dic.m1 <- spDIC(m.1)
##D 
##D ##> dic.m1
##D ##                  [,1]
##D ##bar.D       503.023678
##D ##D.bar.Omega 501.059965
##D ##pD            1.963713
##D ##DIC         504.987392
##D 
##D ##############################
##D ##Spatial model
##D ##############################
##D m.2 <- spLM(Y.2~1, coords=coords, knots=c(6,6,0),
##D              starting=list("phi"=0.1,"sigma.sq"=5, "tau.sq"=5),
##D              sp.tuning=list("phi"=0.03, "sigma.sq"=0.03, "tau.sq"=0.03),
##D              priors=list("phi.Unif"=c(0.06, 3), "sigma.sq.IG"=c(2, 5),
##D                "tau.sq.IG"=c(2, 5)),
##D              cov.model="exponential",
##D              n.samples=2000, verbose=TRUE, n.report=100)
##D 
##D summary(m.2$p.samples)
##D 
##D dic.m2 <- spDIC(m.2)
##D 
##D ##> dic.m2
##D ##$DIC.marg
##D ##                 value
##D ##bar.D       479.904433
##D ##D.bar.Omega 476.856815
##D ##pD            3.047617
##D ##DIC         482.952050
##D 
##D ##$DIC.unmarg
##D ##                value
##D ##bar.D       330.50408
##D ##D.bar.Omega 258.64266
##D ##pD           71.86142
##D ##DIC         402.36550
##D 
##D ## End(Not run)
##D 
## End(Not run)



