### Name: spGLM
### Title: Function for fitting univariate Bayesian generalized linear
###   spatial regression models
### Aliases: spGLM
### Keywords: misc

### ** Examples

## Not run: 
##D ###########################
##D ##Spatial poisson
##D ###########################
##D 
##D ##Generate count data
##D n <- 100
##D 
##D coords <- cbind(runif(n,1,100),runif(n,1,100))
##D 
##D phi <- 3/75
##D sigma.sq <- 2
##D 
##D R <- sigma.sq*exp(-phi*as.matrix(dist(coords)))
##D w <- mvrnorm(1, rep(0,n), R)
##D 
##D x <- as.matrix(rep(1,n))
##D beta <- 0.1
##D y <- rpois(n, exp(x%*%beta+w))
##D 
##D ##Collect samples
##D beta.starting <- coefficients(glm(y~x-1, family="poisson"))
##D beta.tuning <- t(chol(vcov(glm(y~x-1, family="poisson"))))
##D             
##D n.samples <- 25000
##D 
##D m.1 <- spGLM(y~1, family="poisson", coords=coords, 
##D              starting=
##D              list("beta"=beta.starting, "phi"=0.06,"sigma.sq"=1, "w"=0),
##D              tuning=
##D              list("beta"=0.1, "phi"=0.01, "sigma.sq"=0.01, "w"=0.005),
##D              priors=
##D              list("beta.Flat", "phi.Unif"=c(0.03, 0.3), "sigma.sq.IG"=c(2, 1)),
##D              cov.model="exponential",
##D              n.samples=n.samples, verbose=TRUE, n.report=500)
##D 
##D m.1$p.samples[,"phi"] <- 3/m.1$p.samples[,"phi"]
##D 
##D burn.in <- 0.75*n.samples
##D print(summary(mcmc(m.1$p.samples[burn.in:n.samples,])))
##D 
##D beta.hat <- mean(m.1$p.samples[burn.in:n.samples,1])
##D w.hat <- rowMeans(m.1$sp.effects[,burn.in:n.samples])
##D 
##D y.hat <-exp(x%*%beta.hat+w.hat)
##D 
##D ##Take a look
##D par(mfrow=c(1,2))
##D surf <- mba.surf(cbind(coords,y),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf, main="obs")
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(coords, labels=y, cex=1, col="blue")
##D 
##D surf <- mba.surf(cbind(coords,y.hat),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf, main="Fitted counts")
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(coords, labels=round(y.hat,0), cex=1, col="blue")
##D 
##D ###########################
##D ##Spatial logistic
##D ###########################
##D 
##D ##Generate binary data
##D n <- 50
##D 
##D coords <- cbind(runif(n,1,100),runif(n,1,100))
##D 
##D phi <- 3/50
##D sigma.sq <- 1
##D 
##D R <- sigma.sq*exp(-phi*as.matrix(dist(coords)))
##D w <- mvrnorm(1, rep(0,n), R)
##D 
##D x <- as.matrix(rep(1,n))
##D beta <- 0.1
##D p <- 1/(1+exp(-(x%*%beta+w)))
##D y <- rbinom(n, 1, prob=p)
##D 
##D ##Collect samples
##D beta.starting <- coefficients(glm(y~x-1, family="binomial"))
##D beta.tuning <- t(chol(vcov(glm(y~x-1, family="binomial"))))
##D             
##D n.samples <- 50000
##D 
##D m.1 <- spGLM(y~1, family="binomial", coords=coords, 
##D              starting=
##D              list("beta"=beta.starting, "phi"=0.06,"sigma.sq"=1, "w"=0),
##D              tuning=
##D              list("beta"=beta.tuning, "phi"=0.1, "sigma.sq"=0.1, "w"=0.01),
##D              priors=
##D              list("beta.Normal"=list(0,10), "phi.Unif"=c(0.03, 0.3),
##D                   "sigma.sq.IG"=c(2, 1)),
##D              cov.model="exponential",
##D              n.samples=n.samples, verbose=TRUE, n.report=500)
##D 
##D m.1$p.samples[,"phi"] <- 3/m.1$p.samples[,"phi"]
##D 
##D burn.in <- 0.75*n.samples
##D print(summary(mcmc(m.1$p.samples[burn.in:n.samples,])))
##D 
##D beta.hat <- mean(m.1$p.samples[burn.in:n.samples,1])
##D w.hat <- rowMeans(m.1$sp.effects[,burn.in:n.samples])
##D 
##D y.hat <- 1/(1+exp(-(x%*%beta.hat+w.hat)))
##D 
##D ##Take a look
##D par(mfrow=c(1,2))
##D surf <- mba.surf(cbind(coords,y),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf, main="Observed")
##D contour(surf, add=TRUE)
##D points(coords[y==1,], pch=19, cex=1)
##D points(coords[y==0,], cex=1)
##D 
##D surf <- mba.surf(cbind(coords,y.hat),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf, main="Fitted probabilities")
##D contour(surf, add=TRUE)
##D points(coords[y==1,], pch=19, cex=1)
##D points(coords[y==0,], cex=1)
##D 
## End(Not run)



