### Name: spLM
### Title: Function for fitting univariate Bayesian spatial regression
###   models
### Aliases: spLM
### Keywords: misc

### ** Examples

## Not run: 
##D data(rf.n200.dat)
##D 
##D Y <- rf.n200.dat$Y
##D coords <- as.matrix(rf.n200.dat[,c("x.coords","y.coords")])
##D w <- rf.n200.dat$w
##D 
##D ##############################
##D ##Simple spatial regression
##D ##############################
##D m.1 <- spLM(Y~1, coords=coords,
##D              starting=list("phi"=0.6,"sigma.sq"=1, "tau.sq"=1),
##D              sp.tuning=list("phi"=0.01, "sigma.sq"=0.05, "tau.sq"=0.05),
##D              priors=list("phi.Unif"=c(0.3, 3), "sigma.sq.IG"=c(2, 1),
##D                "tau.sq.IG"=c(2, 1)),
##D              cov.model="exponential",
##D              n.samples=1000, verbose=TRUE, n.report=100)
##D 
##D print(summary(m.1$p.samples))
##D plot(m.1$p.samples)
##D 
##D ##Requires MBA package to
##D ##make surfaces
##D library(MBA)
##D par(mfrow=c(1,2))
##D obs.surf <-
##D   mba.surf(cbind(coords, Y), no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(obs.surf, xaxs = "r", yaxs = "r", main="Observed response")
##D points(coords)
##D contour(obs.surf, add=T)
##D 
##D w.hat <- rowMeans(m.1$sp.effects)
##D w.surf <-
##D   mba.surf(cbind(coords, w.hat), no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(w.surf, xaxs = "r", yaxs = "r", main="Estimated random effects")
##D points(coords)
##D points(m.1$knot.coords, pch=19, cex=1)
##D contour(w.surf, add=T)
##D 
##D ##############################
##D ##Predictive process
##D ##############################
##D ##Use some more observations
##D data(rf.n500.dat)
##D 
##D Y <- rf.n500.dat$Y
##D coords <- as.matrix(rf.n500.dat[,c("x.coords","y.coords")])
##D w <- rf.n500.dat$w
##D 
##D m.2 <- spLM(Y~1, coords=coords, knots=c(6,6,0),
##D              starting=list("phi"=0.6,"sigma.sq"=1, "tau.sq"=1),
##D              sp.tuning=list("phi"=0.01, "sigma.sq"=0.01, "tau.sq"=0.01),
##D              priors=list("phi.Unif"=c(0.3, 3), "sigma.sq.IG"=c(2, 1),
##D                "tau.sq.IG"=c(2, 1)),
##D              cov.model="exponential",
##D              modified.pp=FALSE, n.samples=2000, verbose=TRUE, n.report=100)
##D 
##D print(summary(m.2$p.samples))
##D plot(m.2$p.samples)
##D 
##D ##Requires MBA package to
##D ##make surfaces
##D library(MBA)
##D par(mfrow=c(1,2))
##D obs.surf <-
##D   mba.surf(cbind(coords, w), no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(obs.surf, xaxs = "r", yaxs = "r", main="Observed response")
##D points(coords)
##D contour(obs.surf, add=T)
##D 
##D w.hat <- rowMeans(m.2$sp.effects)
##D w.surf <-
##D   mba.surf(cbind(coords, w.hat), no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(w.surf, xaxs = "r", yaxs = "r", main="Estimated random effects")
##D contour(w.surf, add=T)
##D points(coords, pch=1, cex=1)
##D points(m.2$knot.coords, pch=19, cex=1)
##D legend(1.5,2.5, legend=c("Obs.", "Knots"), pch=c(1,19), bg="white")
##D 
##D ##############################
##D ##Modified predictive process
##D ##############################
##D m.3 <- spLM(Y~1, coords=coords, knots=c(6,6,0),
##D              starting=list("phi"=0.6,"sigma.sq"=1, "tau.sq"=1),
##D              sp.tuning=list("phi"=0.01, "sigma.sq"=0.01, "tau.sq"=0.01),
##D              priors=list("phi.Unif"=c(0.3, 3), "sigma.sq.IG"=c(2, 1),
##D                "tau.sq.IG"=c(2, 1)),
##D              cov.model="exponential",
##D              n.samples=2000, verbose=TRUE, n.report=100)
##D 
##D print(summary(m.3$p.samples))
##D plot(m.3$p.samples)
##D 
##D ##Requires MBA package to
##D ##make surfaces
##D library(MBA)
##D par(mfrow=c(1,2))
##D obs.surf <-
##D   mba.surf(cbind(coords, w), no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(obs.surf, xaxs = "r", yaxs = "r", main="Observed response")
##D points(coords)
##D contour(obs.surf, add=T)
##D 
##D w.hat <- rowMeans(m.3$sp.effects)
##D w.surf <-
##D   mba.surf(cbind(coords, w.hat), no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(w.surf, xaxs = "r", yaxs = "r", main="Estimated random effects")
##D contour(w.surf, add=T)
##D points(coords, pch=1, cex=1)
##D points(m.3$knot.coords, pch=19, cex=1)
##D legend(1.5,2.5, legend=c("Obs.", "Knots"), pch=c(1,19), bg="white")
##D 
## End(Not run)



