### Name: spMvGLM
### Title: Function for fitting multivariate Bayesian generalized linear
###   spatial regression models
### Aliases: spMvGLM
### Keywords: misc

### ** Examples

## Not run: 
##D ################################
##D ##Spatial multivariate poisson
##D ################################
##D 
##D ##Generate some data
##D n <- 100
##D q <- 3   
##D nltr <- q*(q-1)/2+q
##D 
##D coords <- cbind(runif(n,1,100),runif(n,1,100))
##D 
##D theta <- rep(3/50,q)
##D 
##D A <- matrix(0,q,q)
##D A[lower.tri(A,TRUE)] <- rnorm(nltr,1,1)
##D K <- A%*%t(A)
##D 
##D Psi <- diag(0,q)
##D 
##D c1 <- mvCovInvLogDet(coords=coords, knots=coords,
##D                      cov.model="exponential",
##D                      V=K, Psi=Psi, theta=theta,
##D                      modified.pp=TRUE, SWM=FALSE)
##D 
##D w <- mvrnorm(1,rep(0,nrow(c1$C)),c1$C)
##D 
##D X <- mkMvX(list(matrix(1,n,1), matrix(1,n,1), matrix(1,n,1)))
##D beta <- c(-1,0,1)
##D y <- rpois(n*q, exp(X%*%beta+w))
##D 
##D y.1 <- y[seq(1,length(y),q)]
##D y.2 <- y[seq(2,length(y),q)]
##D y.3 <- y[seq(3,length(y),q)]
##D 
##D ##Specify starting values and collect samples. For
##D ##a true analysis, several longer chains should be
##D ##run.
##D A.starting <- diag(1,q)[lower.tri(diag(1,q), TRUE)]
##D 
##D beta.starting <- coefficients(glm(y~X-1, family="poisson"))
##D beta.tuning <- t(chol(vcov(glm(y~X-1, family="poisson"))))
##D 
##D n.samples <- 15000
##D 
##D m.1 <- spMvGLM(list(y.1~1,y.2~1,y.3~1), family="poisson", coords=coords,
##D                knots=c(8,8,0),
##D                starting=
##D                list("beta"=beta.starting, "phi"=rep(0.06,q),
##D                     "A"=A.starting, "w"=0), 
##D                tuning=
##D                list("beta"=beta.tuning, "phi"=rep(0.01,q),
##D                     "A"=rep(0.005,nltr), "w"=0.001),
##D                priors=
##D                list("beta.Flat", "phi.Unif"=rep(c(0.03, 0.3),q),
##D                     "K.IW"=list(q+1, diag(0.1,q))),
##D                cov.model="exponential",
##D                n.samples=n.samples, verbose=TRUE, n.report=500)
##D 
##D m.1$p.samples[,paste("phi_",1:q,sep="")] <-
##D   3/m.1$p.samples[,paste("phi_",1:q,sep="")]
##D 
##D burn.in <- 0.75*n.samples
##D print(summary(mcmc(m.1$p.samples[burn.in:n.samples,])))
##D 
##D beta.hat <- colMeans(m.1$p.samples[burn.in:n.samples,1:q])
##D w.hat <- rowMeans(m.1$sp.effects[,burn.in:n.samples])
##D 
##D y.hat <- exp(X%*%beta.hat+w.hat)
##D 
##D y.hat.1 <- y.hat[seq(1,length(y.hat),q)]
##D y.hat.2 <- y.hat[seq(2,length(y.hat),q)]
##D y.hat.3 <- y.hat[seq(3,length(y.hat),q)]
##D 
##D ##Take a look
##D par(mfrow=c(3,2))
##D surf <- mba.surf(cbind(coords,y.1),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf, main="Observed counts")
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(coords, labels=y.1, cex=1, col="blue")
##D 
##D surf <- mba.surf(cbind(coords,y.hat.1),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf, main="Fitted counts")
##D contour(surf, add=TRUE)
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(coords, labels=round(y.hat.1,0), cex=1, col="blue")
##D 
##D surf <- mba.surf(cbind(coords,y.2),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf)
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(coords, labels=y.2, cex=1, col="blue")
##D 
##D surf <- mba.surf(cbind(coords,y.hat.2),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf)
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(coords, labels=round(y.hat.2,0), cex=1, col="blue")
##D 
##D surf <- mba.surf(cbind(coords,y.3),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf)
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(coords, labels=y.3, cex=1, col="blue")
##D 
##D surf <- mba.surf(cbind(coords,y.hat.3),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf)
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(coords, labels=round(y.hat.3,0), cex=1, col="blue")
##D 
##D 
##D 
## End(Not run)



