### Name: spMvLM
### Title: Function for fitting multivariate Bayesian spatial regression
###   models
### Aliases: spMvLM
### Keywords: misc

### ** Examples

## Not run: 
##D ###################################
##D ##Multivariate spatial regression
##D ###################################
##D 
##D ##Generate some data
##D n <- 50 ##observed
##D q <- 3   
##D nltr <- q*(q-1)/2+q
##D 
##D coords <- cbind(runif(n),runif(n))
##D theta <- rep(3/0.5,q)
##D 
##D A <- matrix(0,q,q)
##D A[lower.tri(A,TRUE)] <- rnorm(nltr, 5, 1)
##D K <- A%*%t(A)
##D 
##D Psi <- diag(1,q)
##D 
##D c1 <- mvCovInvLogDet(coords=coords, knots=coords,
##D                      cov.model="exponential",
##D                      V=K, Psi=Psi, theta=theta,
##D                      modified.pp=FALSE, SWM=FALSE)
##D 
##D w <- mvrnorm(1,rep(0,nrow(c1$C)),c1$C)
##D 
##D w.1 <- w[seq(1,length(w),q)]
##D w.2 <- w[seq(2,length(w),q)]
##D w.3 <- w[seq(3,length(w),q)]
##D 
##D ##Specify starting values and collect samples
##D K.starting <- diag(1,q)[lower.tri(diag(1,q), TRUE)]
##D Psi.starting <- diag(1,q)[lower.tri(diag(1,q), TRUE)]
##D 
##D n.samples <- 5000
##D 
##D m.1 <- spMvLM(list(w.1~1,w.2~1,w.3~1), coords=coords,
##D               starting=list("beta"=rep(1,q), "phi"=rep(3/0.5,q),
##D                 "A"=K.starting), 
##D               sp.tuning=list("phi"=rep(0.1,q),
##D                 "A"=rep(0.1,nltr)),
##D               priors=list("phi.Unif"=rep(c(3/1,3/0.1),q),
##D                 "K.IW"=list(q+1, diag(1,q))),
##D               modified.pp=TRUE, cov.model="exponential",
##D               n.samples=n.samples, verbose=TRUE, n.report=100)
##D 
##D m.1$p.samples[,paste("phi_",1:q,sep="")] <-
##D   3/m.1$p.samples[,paste("phi_",1:q,sep="")]
##D 
##D burn.in <- 0.50*n.samples
##D 
##D print(summary(mcmc(m.1$p.samples[burn.in:n.samples,])))
##D 
##D w.hat <- rowMeans(m.1$sp.effects[,burn.in:ncol(m.1$sp.effects)])
##D w.hat.1 <- w.hat[seq(1,length(w.hat),q)]
##D w.hat.2 <- w.hat[seq(2,length(w.hat),q)]
##D w.hat.3 <- w.hat[seq(3,length(w.hat),q)]
##D 
##D ##Take a look
##D par(mfrow=c(3,2))
##D surf <- mba.surf(cbind(coords,w.1),
##D                  no.X=100, no.Y=100, extend=T)$xyz.est
##D image(surf); contour(surf, add=TRUE)
##D 
##D surf <- mba.surf(cbind(coords,w.hat.1),
##D                  no.X=100, no.Y=100, extend=T)$xyz.est
##D image(surf); contour(surf, add=TRUE)
##D points(m.1$knot.coords, pch=19, cex=1)
##D 
##D surf <- mba.surf(cbind(coords,w.2),
##D                  no.X=100, no.Y=100, extend=T)$xyz.est
##D image(surf); contour(surf, add=TRUE)
##D 
##D surf <- mba.surf(cbind(coords,w.hat.2),
##D                  no.X=100, no.Y=100, extend=T)$xyz.est
##D image(surf); contour(surf, add=TRUE)
##D points(m.1$knot.coords, pch=19, cex=1)
##D 
##D surf <- mba.surf(cbind(coords,w.3),
##D                  no.X=100, no.Y=100, extend=T)$xyz.est
##D image(surf); contour(surf, add=TRUE)
##D 
##D surf <- mba.surf(cbind(coords,w.hat.3),
##D                  no.X=100, no.Y=100, extend=T)$xyz.est
##D image(surf); contour(surf, add=TRUE)
##D points(m.1$knot.coords, pch=19, cex=1)
##D 
## End(Not run)



