### Name: spPredict
### Title: Prediction for new points given a spGGT, spLM, spMvLM, spGLM,
###   spMvGLM, or bayesGeostatExact object
### Aliases: spPredict
### Keywords: misc

### ** Examples

## Not run: 
##D ##Portions of this example requires MBA package to make surfaces
##D library(MBA)
##D 
##D #########################
##D ##Prediction for spMvGLM
##D #########################
##D 
##D ##Generate some count data
##D n <- 100
##D q <- 3   
##D nltr <- q*(q-1)/2+q
##D 
##D coords <- cbind(runif(n,1,100),runif(n,1,100))
##D 
##D theta <- rep(3/50,q)
##D 
##D A <- matrix(0,q,q)
##D A[lower.tri(A,TRUE)] <- rnorm(nltr,1,1)
##D K <- A%*%t(A)
##D 
##D Psi <- diag(0,q)
##D 
##D c1 <- mvCovInvLogDet(coords=coords, knots=coords,
##D                      cov.model="exponential",
##D                      V=K, Psi=Psi, theta=theta,
##D                      modified.pp=TRUE, SWM=FALSE)
##D 
##D w <- mvrnorm(1,rep(0,nrow(c1$C)),c1$C)
##D 
##D X <- mkMvX(list(matrix(1,n,1), matrix(1,n,1), matrix(1,n,1)))
##D beta <- c(-1,0,1)
##D y <- rpois(n*q, exp(X%*%beta+w))
##D 
##D y.1 <- y[seq(1,length(y),q)]
##D y.2 <- y[seq(2,length(y),q)]
##D y.3 <- y[seq(3,length(y),q)]
##D 
##D ##Specify starting values and collect samples. For
##D ##a true analysis, several longer chains should be
##D ##run.
##D A.starting <- diag(1,q)[lower.tri(diag(1,q), TRUE)]
##D 
##D beta.starting <- coefficients(glm(y~X-1, family="poisson"))
##D beta.tuning <- t(chol(vcov(glm(y~X-1, family="poisson"))))
##D 
##D n.samples <- 5000
##D 
##D m.1 <- spMvGLM(list(y.1~1,y.2~1,y.3~1), family="poisson", coords=coords,
##D                knots=c(8,8,0),
##D                starting=
##D                list("beta"=beta.starting, "phi"=rep(0.06,q),
##D                     "A"=A.starting, "w"=0), 
##D                tuning=
##D                list("beta"=beta.tuning, "phi"=rep(0.01,q),
##D                     "A"=rep(0.005,nltr), "w"=0.001),
##D                priors=
##D                list("beta.Flat", "phi.Unif"=rep(c(0.03, 0.3),q),
##D                     "K.IW"=list(q+1, diag(0.1,q))),
##D                cov.model="exponential",
##D                n.samples=n.samples, verbose=TRUE, n.report=500)
##D 
##D pred.coords <- expand.grid(seq(0,100,10), seq(0,100,10))
##D m <- nrow(pred.coords)
##D pred.covars <- mkMvX(list(matrix(1,m,1), matrix(1,m,1), matrix(1,m,1)))
##D 
##D out <-
##D   spPredict(m.1, start=2000, pred.coords=pred.coords, pred.covars=pred.covars)
##D 
##D y.hat <- rowMeans(out$y.pred)
##D 
##D y.hat.1 <- y.hat[seq(1,length(y.hat),q)]
##D y.hat.2 <- y.hat[seq(2,length(y.hat),q)]
##D y.hat.3 <- y.hat[seq(3,length(y.hat),q)]
##D 
##D ##Take a look
##D par(mfrow=c(3,2))
##D surf <- mba.surf(cbind(coords,y.1),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf, main="Observed counts")
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(coords, labels=y.1, cex=1, col="blue")
##D 
##D surf <- mba.surf(cbind(pred.coords,y.hat.1),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf, main="Fitted counts")
##D contour(surf, add=TRUE)
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(pred.coords, labels=round(y.hat.1,0), cex=1, col="green")
##D 
##D surf <- mba.surf(cbind(coords,y.2),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf)
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(coords, labels=y.2, cex=1, col="blue")
##D 
##D surf <- mba.surf(cbind(pred.coords,y.hat.2),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf)
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(pred.coords, labels=round(y.hat.2,0), cex=1, col="green")
##D 
##D surf <- mba.surf(cbind(coords,y.3),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf)
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(coords, labels=y.3, cex=1, col="blue")
##D 
##D surf <- mba.surf(cbind(pred.coords,y.hat.3),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf)
##D contour(surf, drawlabels=FALSE, add=TRUE)
##D text(pred.coords, labels=round(y.hat.3,0), cex=1, col="green")
##D 
##D #########################
##D ##Prediction for spGLM
##D #########################
##D 
##D ##Generate count data
##D n <- 300
##D 
##D coords <- cbind(runif(n,1,100),runif(n,1,100))
##D 
##D phi <- 3/75
##D sigma.sq <- 3
##D 
##D R <- sigma.sq*exp(-phi*as.matrix(dist(coords)))
##D w <- mvrnorm(1, rep(0,n), R)
##D 
##D x <- as.matrix(rep(1,n))
##D beta <- 0.1
##D y <- rpois(n, exp(x%*%beta+w))
##D 
##D ##Collect samples
##D beta.starting <- coefficients(glm(y~x-1, family="poisson"))
##D beta.tuning <- t(chol(vcov(glm(y~x-1, family="poisson"))))
##D             
##D n.samples <- 15000
##D 
##D m.1 <- spGLM(y~1, family="poisson", coords=coords, knots=c(8,8,0),
##D              starting=
##D              list("beta"=beta.starting, "phi"=0.06,
##D                   "sigma.sq"=1, "w"=0),
##D              tuning=
##D              list("beta"=beta.tuning, "phi"=0.1,
##D                   "sigma.sq"=0.1, "w"=0.001),
##D              priors=
##D              list("beta.Flat", "phi.Unif"=c(0.03, 0.3),
##D                   "sigma.sq.IG"=c(2, 1)),
##D              cov.model="exponential",
##D              n.samples=n.samples, verbose=TRUE, n.report=500)
##D 
##D ##Make prediction grid
##D pred.coords <- expand.grid(seq(0,100,5), seq(0,100,5))
##D out <- spPredict(m.1, start=10000, thin=2, pred.coords=pred.coords,
##D                  pred.covars=as.matrix(rep(1,nrow(pred.coords))))
##D 
##D y.pred <- rowMeans(out$y.pred)
##D 
##D ##Take a look
##D par(mfrow=c(1,2))
##D surf <-
##D   mba.surf(cbind(coords,y),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf, main="Observed counts")
##D contour(surf, add=TRUE)
##D 
##D surf <-
##D   mba.surf(cbind(pred.coords, y.pred),no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(surf, main="Predicted counts")
##D contour(surf, add=TRUE)
##D points(pred.coords, pch=19, cex=0.5, col="blue")
##D 
##D #########################
##D ##Prediction for spMvLM
##D #########################
##D 
##D ##Generate some data
##D n <- 100 ##observed
##D m <- 50  ##predict
##D N <- n+m
##D q <- 3   
##D nltr <- q*(q-1)/2+q
##D 
##D coords <- cbind(runif(N),runif(N))
##D theta <- rep(3/0.5,q)
##D 
##D A <- matrix(0,q,q)
##D A[lower.tri(A,TRUE)] <- rnorm(nltr, 5, 1)
##D V <- A%*%t(A)
##D 
##D Psi <- diag(1,q)
##D 
##D c1 <- mvCovInvLogDet(coords=coords, knots=coords,
##D                      cov.model="exponential",
##D                      V=V, Psi=Psi, theta=theta)
##D 
##D w <- mvrnorm(1,rep(0,nrow(c1$C)),c1$C)
##D obs.w <- w[1:(n*q)]
##D 
##D w.1 <- obs.w[seq(1,length(obs.w),q)]
##D w.2 <- obs.w[seq(2,length(obs.w),q)]
##D w.3 <- obs.w[seq(3,length(obs.w),q)]
##D 
##D ##Specify starting values and collect samples
##D A.starting <- diag(1,q)[lower.tri(diag(1,q), TRUE)]
##D L.starting <- diag(1,q)[lower.tri(diag(1,q), TRUE)]
##D 
##D n.samples <- 1000
##D 
##D obs.coords <- coords[1:n,]
##D 
##D m.1 <- spMvLM(list(w.1~1,w.2~1,w.3~1), coords=obs.coords,
##D               knots=c(8,8,0),
##D               starting=list("beta"=rep(1,q), "phi"=rep(3/0.5,q),
##D                 "nu"=rep(1,q), "A"=A.starting, "L"=L.starting), 
##D               sp.tuning=list("phi"=rep(0.1,q), "nu"=rep(0.1,q),
##D                 "A"=rep(0.1,nltr), "L"=rep(0.1,nltr)),
##D               priors=list("phi.Unif"=rep(c(3/1,3/0.1),q),
##D                 "nu.Unif"=rep(c(0.1,2),q),
##D                 "K.IW"=list(q+1, diag(1,q)), "Psi.IW"=list(q+1, diag(1,q))),
##D               modified.pp=FALSE, cov.model="matern",
##D               n.samples=n.samples, verbose=TRUE, n.report=100)
##D 
##D ##Predict for holdout set
##D pred.coords <- coords[(n+1):nrow(coords),]
##D pred.covars <- mkMvX(list(matrix(1,m,1), matrix(1,m,1), matrix(1,m,1)))
##D 
##D pred <- spPredict(m.1, pred.coords, pred.covars)
##D 
##D ho.w <- w[(n*q+1):length(w)]
##D ho.w.1 <- ho.w[seq(1,length(ho.w),q)]
##D ho.w.2 <- ho.w[seq(2,length(ho.w),q)]
##D ho.w.3 <- ho.w[seq(3,length(ho.w),q)]
##D 
##D burn.in <- 500
##D 
##D pred.w <- rowMeans(pred$y.pred[,burn.in:ncol(pred$y.pred)])
##D pred.w.1 <- pred.w[seq(1,length(pred.w),q)]
##D pred.w.2 <- pred.w[seq(2,length(pred.w),q)]
##D pred.w.3 <- pred.w[seq(3,length(pred.w),q)]
##D 
##D ##Take a look
##D par(mfrow=c(3,2))
##D surf <- mba.surf(cbind(obs.coords,w.1),
##D                  no.X=100, no.Y=100, extend=T)$xyz.est
##D image(surf, main="Observed"); contour(surf, add=TRUE)
##D 
##D surf <- mba.surf(cbind(pred.coords,pred.w.1),
##D                  no.X=100, no.Y=100, extend=T)$xyz.est
##D image(surf, main="Predicted"); contour(surf, add=TRUE)
##D points(m.1$knot.coords, pch=19, cex=1)
##D 
##D surf <- mba.surf(cbind(obs.coords,w.2),
##D                  no.X=100, no.Y=100, extend=T)$xyz.est
##D image(surf); contour(surf, add=TRUE)
##D 
##D surf <- mba.surf(cbind(pred.coords,pred.w.2),
##D                  no.X=100, no.Y=100, extend=T)$xyz.est
##D image(surf); contour(surf, add=TRUE)
##D points(m.1$knot.coords, pch=19, cex=1)
##D 
##D surf <- mba.surf(cbind(obs.coords,w.3),
##D                  no.X=100, no.Y=100, extend=T)$xyz.est
##D image(surf); contour(surf, add=TRUE)
##D 
##D surf <- mba.surf(cbind(pred.coords,pred.w.3),
##D                  no.X=100, no.Y=100, extend=T)$xyz.est
##D image(surf); contour(surf, add=TRUE)
##D points(m.1$knot.coords, pch=19, cex=1)
##D 
##D ###########################################
##D ##  Prediction for bayesGeostatExact
##D ###########################################
##D data(FBC07.dat)
##D Y <- FBC07.dat[1:150,"Y.2"]
##D coords <- as.matrix(FBC07.dat[1:150,c("coord.X", "coord.Y")])
##D 
##D n.samples <-1000
##D n = length(Y)
##D p = 1
##D 
##D phi <- 0.15
##D nu <- 0.5
##D 
##D beta.prior.mean <- as.matrix(rep(0, times=p))
##D beta.prior.precision <- matrix(0, nrow=p, ncol=p)
##D 
##D alpha <- 5/5
##D 
##D sigma.sq.prior.shape <- 2.0
##D sigma.sq.prior.rate <- 5.0
##D 
##D ##############################
##D ##Simple linear model with
##D ##the default exponential
##D ##spatial decay function
##D ##############################
##D m.1 <- bayesGeostatExact(Y~1, n.samples=n.samples,
##D                            beta.prior.mean=beta.prior.mean,
##D                            beta.prior.precision=beta.prior.precision,
##D                            coords=coords, phi=phi, alpha=alpha,
##D                            sigma.sq.prior.shape=sigma.sq.prior.shape,
##D                            sigma.sq.prior.rate=sigma.sq.prior.rate,
##D                            sp.effects=TRUE)
##D 
##D ##Now prediction
##D set.seed(1)
##D pred.coords <- expand.grid(seq(0,100,length=10),seq(0,100,length=10))
##D pred.covars <- as.matrix(rep(1,nrow(pred.coords)))
##D 
##D m.1.pred <- spPredict(m.1, pred.coords=pred.coords,
##D                        pred.covars=pred.covars, thin=5)
##D 
##D par(mfrow=c(2,2))
##D obs.surf <-
##D   mba.surf(cbind(coords, Y), no.X=100, no.Y=100, extend=T)$xyz.est
##D image(obs.surf, xaxs = "r", yaxs = "r", main="Observed response")
##D points(coords, pch=19, cex=1, col="green")
##D contour(obs.surf, add=T)
##D 
##D w.hat <- rowMeans(m.1$sp.effects)
##D w.surf <-
##D   mba.surf(cbind(coords, w.hat), no.X=100, no.Y=100, extend=T)$xyz.est
##D image(w.surf, xaxs = "r", yaxs = "r", main="Random effects")
##D points(coords, pch=19, cex=1, col="green")
##D contour(w.surf, add=T)
##D 
##D y.hat <- rowMeans(m.1.pred)
##D y.surf <-
##D   mba.surf(cbind(pred.coords, y.hat), no.X=100, no.Y=100, extend=T)$xyz.est
##D image(y.surf, xaxs = "r", yaxs = "r", main="Predicted response")
##D points(pred.coords, pch=19, cex=1, col="black")
##D rect(0, 0, 50, 50, col=NA, border="green")
##D contour(y.surf, add=T)
##D 
##D y.var <- apply(m.1.pred, 1, var)
##D y.surf <-
##D   mba.surf(cbind(pred.coords, y.var), no.X=100, no.Y=100, extend=T)$xyz.est
##D image(y.surf, xaxs = "r", yaxs = "r", main="Predicted response\nvariance")
##D points(coords, pch=19, cex=1, col="green")
##D points(pred.coords, pch=19, cex=1, col="black")
##D rect(0, 0, 50, 50, col=NA, border="green")
##D contour(y.surf, add=T)
##D  
##D ###########################################
##D ##       Prediction for spLM
##D ###########################################
##D data(rf.n200.dat)
##D 
##D Y <- rf.n200.dat$Y
##D coords <- as.matrix(rf.n200.dat[,c("x.coords","y.coords")])
##D w <- rf.n200.dat$w
##D 
##D pred.coords <- expand.grid(seq(1,10,1), seq(1,10,1))
##D n.pred <- nrow(pred.coords)
##D 
##D ###############################
##D ##Prediction with a spLM model
##D ###############################
##D m.2 <- spLM(Y~1, coords=coords,
##D              starting=list("phi"=0.6,"sigma.sq"=1, "tau.sq"=1),
##D              sp.tuning=list("phi"=0.01, "sigma.sq"=0.05, "tau.sq"=0.05),
##D              priors=list("phi.Unif"=c(0.3, 3), "sigma.sq.IG"=c(2, 1),
##D                "tau.sq.IG"=c(2, 1)),
##D              cov.model="exponential",
##D              n.samples=1000, verbose=TRUE, n.report=100)
##D 
##D pred <- spPredict(m.2, pred.coords,
##D                    pred.covars=as.matrix(rep(1,n.pred)))
##D 
##D par(mfrow=c(1,2))
##D obs.surf <-
##D   mba.surf(cbind(coords, Y), no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(obs.surf, xaxs = "r", yaxs = "r", main="Observed response")
##D points(coords)
##D contour(obs.surf, add=T)
##D 
##D y.hat <- rowMeans(pred$y.pred)
##D y.pred.surf <-
##D   mba.surf(cbind(pred.coords, y.hat), no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(y.pred.surf, xaxs = "r", yaxs = "r", main="Predicted response")
##D points(coords, pch=1, cex=1)
##D points(pred.coords, pch=19, cex=1)
##D contour(y.pred.surf, add=T)
##D legend(1.5,2.5, legend=c("Obs.", "Pred."), pch=c(1,19), bg="white")
##D 
##D ###############################
##D ##Prediction with a spLM
##D ##predictive process model
##D ###############################
##D m.3 <- spLM(Y~1, coords=coords, knots=c(6,6,0),
##D              starting=list("phi"=0.6,"sigma.sq"=1, "tau.sq"=1),
##D              sp.tuning=list("phi"=0.01, "sigma.sq"=0.01, "tau.sq"=0.01),
##D              priors=list("phi.Unif"=c(0.3, 3), "sigma.sq.IG"=c(2, 1),
##D                "tau.sq.IG"=c(2, 1)),
##D              cov.model="exponential",
##D              n.samples=2000, verbose=TRUE, n.report=100)
##D 
##D print(summary(m.3$p.samples))
##D plot(m.3$p.samples)
##D 
##D pred <- spPredict(m.3, pred.coords,
##D                    pred.covars=as.matrix(rep(1,n.pred)))
##D 
##D par(mfrow=c(1,2))
##D obs.surf <-
##D   mba.surf(cbind(coords, Y), no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(obs.surf, xaxs = "r", yaxs = "r", main="Observed response")
##D points(coords)
##D contour(obs.surf, add=T)
##D 
##D y.hat <- rowMeans(pred$y.pred)
##D y.pred.surf <-
##D   mba.surf(cbind(pred.coords, y.hat), no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D image(y.pred.surf, xaxs = "r", yaxs = "r", main="Predicted response")
##D points(coords, pch=1, cex=1)
##D points(m.3$knot.coords, pch=3, cex=1)
##D points(pred.coords, pch=19, cex=1)
##D contour(y.pred.surf, add=T)
##D legend(1.5,2.5, legend=c("Obs.", "Knots", "Pred."),
##D        pch=c(1,3,19), bg="white")
##D 
##D ###########################################
##D ##       Prediction for spGGT
##D ###########################################
##D data(FBC07.dat)
##D 
##D ##Divide the data into model and prediction sets
##D Y.1 <- FBC07.dat[1:100,"Y.1"]
##D Y.2 <- FBC07.dat[1:100,"Y.2"]
##D model.coords <- as.matrix(FBC07.dat[1:100,c("coord.X", "coord.Y")])
##D pred.coords <- as.matrix(FBC07.dat[151:200,c("coord.X", "coord.Y")])
##D 
##D #############################
##D ##   Univariate model
##D #############################
##D 
##D ##Fit some model with spGGT.
##D K.prior <- prior(dist="IG", shape=2, scale=5)
##D Psi.prior <- prior(dist="IG", shape=2, scale=5)
##D phi.prior <- prior(dist="UNIF", a=0.06, b=3)
##D 
##D var.update.control <-
##D   list("K"=list(starting=5, tuning=0.5, prior=K.prior),
##D        "Psi"=list(starting=5, tuning=0.5, prior=Psi.prior),
##D        "phi"=list(starting=0.1, tuning=0.5, prior=phi.prior)
##D        )
##D 
##D beta.control <- list(update="GIBBS", prior=prior(dist="FLAT"))
##D 
##D run.control <- list("n.samples"=1000)
##D 
##D Fit <- spGGT(formula=Y.2~1, run.control=run.control,
##D               coords=model.coords,
##D               var.update.control=var.update.control,
##D               beta.update.control=beta.control,
##D               cov.model="exponential")
##D 
##D ##Now make predictions for the holdout set.
##D ##Step 1. make the design matrix for the prediction points.
##D pred.covars <- as.matrix(rep(1, nrow(pred.coords)))
##D 
##D ##Step 2. call spPredict.
##D Pred <- spPredict(Fit, pred.covars=pred.covars,
##D                    pred.coords=pred.coords)
##D 
##D ##Step 3. check out the predicted random effects and
##D ##predicted response variable.
##D 
##D Pred.sp.effects.surf <-
##D   mba.surf(cbind(pred.coords, rowMeans(Pred$pred.sp.effects)),
##D            no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D 
##D Pred.Y.surf <-
##D   mba.surf(cbind(pred.coords, rowMeans(Pred$pred.y)),
##D            no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D 
##D par(mfrow=c(1,2))
##D image(Pred.sp.effects.surf, xaxs="r", yaxs="r",
##D       main="Predicted random spatial effects")
##D contour(Pred.sp.effects.surf, add=TRUE)
##D 
##D image(Pred.Y.surf, xaxs="r", yaxs="r",
##D       main="Predicted Y.2")
##D contour(Pred.Y.surf, add=TRUE)
##D 
##D #############################
##D ##   Multivariate models
##D #############################
##D 
##D ##Fit some model with spGGT.
##D K.prior <- prior(dist="IWISH", df=2, S=diag(c(3, 6)))
##D Psi.prior <- prior(dist="IWISH", df=2, S=diag(c(7, 5)))
##D phi.prior <- prior(dist="UNIF", a=0.06, b=3)
##D 
##D K.starting <- matrix(c(2,-3, 0, 1), 2, 2)
##D Psi.starting <- diag(c(3, 2))
##D 
##D var.update.control <-
##D   list("K"=list(starting=K.starting, tuning=diag(c(0.1, 0.5, 0.1)),
##D          prior=K.prior),
##D        "Psi"=list(starting=Psi.starting, tuning=diag(c(0.1, 0.5, 0.1)),
##D          prior=Psi.prior),
##D        "phi"=list(starting=0.1, tuning=0.5,
##D          prior=list(phi.prior, phi.prior))
##D        )
##D 
##D beta.control <- list(update="GIBBS", prior=prior(dist="FLAT"))
##D 
##D run.control <- list("n.samples"=1000, "sp.effects"=FALSE)
##D 
##D Fit.mv <-
##D   spGGT(formula=list(Y.1~1, Y.2~1), run.control=run.control,
##D          coords=model.coords,
##D          var.update.control=var.update.control,
##D          beta.update.control=beta.control,
##D          cov.model="exponential")
##D 
##D ##Now make predictions for the holdout set.
##D ##Step 1. make the design matrix for the prediction points using
##D ##the mkMvX function.
##D pred.covars.1 <- as.matrix(rep(1, nrow(pred.coords)))
##D pred.covars.2 <- as.matrix(rep(1, nrow(pred.coords)))
##D 
##D pred.covars.mv <- mkMvX(list(pred.covars.1, pred.covars.2))
##D 
##D ##Step 2. call spPredict.
##D Pred.mv <- spPredict(Fit.mv, pred.covars=pred.covars.mv,
##D                       pred.coords=pred.coords)
##D 
##D ##Step 3. check out the predicted random effects and
##D ##predicted response variables.   Recall, these are
##D ##organized as m consecutive rows for each point.
##D Pred.sp.effects.1 <-
##D   Pred.mv$pred.sp.effects[seq(1, nrow(Pred.mv$pred.sp.effects), 2),]
##D 
##D Pred.sp.effects.2 <-
##D   Pred.mv$pred.sp.effects[seq(2, nrow(Pred.mv$pred.sp.effects), 2),]
##D 
##D Pred.Y.1 <-
##D   Pred.mv$pred.sp.effects[seq(1, nrow(Pred.mv$pred.y), 2),]
##D 
##D Pred.Y.2 <-
##D   Pred.mv$pred.sp.effects[seq(2, nrow(Pred.mv$pred.y), 2),]
##D 
##D ##Then map.
##D Pred.sp.effects.1.surf <-
##D   mba.surf(cbind(pred.coords, rowMeans(Pred.sp.effects.1)),
##D            no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D 
##D Pred.sp.effects.2.surf <-
##D   mba.surf(cbind(pred.coords, rowMeans(Pred.sp.effects.2)),
##D            no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D 
##D Pred.Y.1.surf <-
##D   mba.surf(cbind(pred.coords, rowMeans(Pred.Y.1)),
##D            no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D 
##D Pred.Y.2.surf <-
##D   mba.surf(cbind(pred.coords, rowMeans(Pred.Y.2)),
##D            no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D 
##D par(mfrow=c(2,2))
##D image(Pred.sp.effects.surf, xaxs="r", yaxs="r",
##D       main="Predicted random spatial effects Y.1")
##D contour(Pred.sp.effects.1.surf, add=TRUE)
##D 
##D image(Pred.sp.effects.surf, xaxs="r", yaxs="r",
##D       main="Predicted random spatial effects Y.2")
##D contour(Pred.sp.effects.2.surf, add=TRUE)
##D 
##D image(Pred.sp.effects.surf, xaxs="r", yaxs="r",
##D       main="Predicted Y.1")
##D contour(Pred.Y.1.surf, add=TRUE)
##D 
##D image(Pred.sp.effects.surf, xaxs="r", yaxs="r",
##D       main="Predicted Y.2")
##D contour(Pred.Y.2.surf, add=TRUE)
##D 
## End(Not run)



